ShinyEnv:Use("ShinyStats")

local L = ShinyLocale


CLASS_HUNTER = "HUNTER"
CLASS_WARLOCK = "WARLOCK"
CLASS_PRIEST = "PRIEST"
CLASS_PALADIN = "PALADIN"
CLASS_MAGE = "MAGE"
CLASS_ROGUE = "ROGUE"
CLASS_DRUID = "DRUID"
CLASS_SHAMAN = "SHAMAN"
CLASS_WARRIOR = "WARRIOR"
CLASS_DEATHKNIGHT = "DEATHKNIGHT"
CLASS_MONK = "MONK"
CLASS_DEMONHUNTER = "DEMONHUNTER"


PARSE_TEXT_TEMPLATE_PATTERN = [[{(%d+)}]]

PATTERN_CATEGORY_CHANCE    = 1
PATTERN_CATEGORY_ENCHANT   = 2
PATTERN_CATEGORY_EQUIP     = 4
PATTERN_CATEGORY_LEGACY    = 8
PATTERN_CATEGORY_LINE      = 16
PATTERN_CATEGORY_OTHER     = 32
PATTERN_CATEGORY_PARTIAL   = 64
PATTERN_CATEGORY_SPECIAL   = 128
PATTERN_CATEGORY_USE       = 256
PATTERN_CATEGORY_MULTIPLE  = 512


PATTERN_CHANCE      = "CHANCE"
PATTERN_ENCHANT     = "ENCHANT"
PATTERN_EQUIP       = "EQUIP"
PATTERN_LEGACY      = "LEGACY"
PATTERN_LINE        = "LINE"
PATTERN_OTHER       = "OTHER"
PATTERN_PARTIAL     = "PARTIAL"
PATTERN_SPECIAL     = "SPECIAL"
PATTERN_USE         = "USE"
PATTERN_MULTIPLE    = "MULTIPLE"


PATTERN_CATEGORY_MAP = {
	[PATTERN_CHANCE]    = PATTERN_CATEGORY_CHANCE,
	[PATTERN_ENCHANT]   = PATTERN_CATEGORY_ENCHANT,
	[PATTERN_EQUIP]     = PATTERN_CATEGORY_EQUIP,
	[PATTERN_LEGACY]    = PATTERN_CATEGORY_LEGACY,
	[PATTERN_LINE]      = PATTERN_CATEGORY_LINE,
	[PATTERN_OTHER]     = PATTERN_CATEGORY_OTHER,
	[PATTERN_PARTIAL]   = PATTERN_CATEGORY_PARTIAL,
	[PATTERN_SPECIAL]   = PATTERN_CATEGORY_SPECIAL,
	[PATTERN_USE]       = PATTERN_CATEGORY_USE,
	[PATTERN_MULTIPLE]  = PATTERN_CATEGORY_MULTIPLE,
}


PROC_PATTERN_REPLACEMENT_MAP = {
	[L["^Equip: Your damaging spells have a chance to (.+)"]]                      = L["Chance on: Damaging Spells"],
	[L["^Equip: Your damaging spellcasts have a chance to (.+)"]]                  = L["Chance on: Damaging Spellcasts"],
	[L["^Equip: Your damaging spells and abilities have a chance to (.+)"]]        = L["Chance on: Damaging Spells, Abilities"],

	[L["^Equip: Your healing spells have a chance to (.+)"]]                       = L["Chance on: Healing Spells"],
	[L["^Equip: Your healing spellcasts have a chance to (.+)"]]                   = L["Chance on: Healing Spellcasts"],
	[L["^Equip: Your healing spells and abilities have a chance to (.+)"]]         = L["Chance on: Healing Spells, Abilities"],
	[L["^Equip: Your healing effects have a chance to (.+)"]]                      = L["Chance on: Healing Effects"],
	[L["^Equip: When you heal you have a chance to (.+)"]]                         = L["Chance on: Healing"],

	[L["^Equip: Your spells and abilities have a chance to (.+)"]]			       = L["Chance on: Spells, Abilities"],
	[L["^Equip: When you deal damage or heal a target you have a chance to (.+)"]] = L["Chance on: Dealing Damage, Healing"],
	[L["^Equip: When you heal or deal damage you have a chance to (.+)"]]          = L["Chance on: Dealing Damage, Healing"],
	[L["^Equip: Your ranged attacks and spells have a chance to (.+)"]]            = L["Chance on: Ranged Attacks, Spells"],

	[L["^Equip: Your ranged attacks have a chance to (.+)"]]                       = L["Chance on: Ranged Attacks"],
	[L["^Equip: Your melee attacks have a chance to (.+)"]]                        = L["Chance on: Melee Attacks"],
	[L["^Equip: Your critical autoattacks have a chance to (.+)"]]                 = L["Chance on: Critical Auto-Attacks"],
	[L["^Equip: When your attacks hit you have a chance to (.+)"]]                 = L["Chance on: Hit Attacks"],
	[L["^Equip: Your attacks have a chance to (.+)"]]                              = L["Chance on: Attacks"],

	[L["^Equip: When you deal damage you have a chance to (.+)"]]                  = L["Chance on: Dealing Damage"],
	[L["^Equip: Taking damage has a chance to (.+)"]]                              = L["Chance on: Taking Damage"],
	[L["^Equip: Chance on being hit to (.+)"]]			                           = L["Chance on: Being Hit"],
}


--[[  C  O  L  O  R  S  ]]--

SHINY_AGILITY                  = "AGILITY"
SHINY_ARMOR                    = "ARMOR"
SHINY_ARTIFACT_RELIC_ITEMLEVEL = "ARTIFACT_RELIC_ITEMLEVEL"
SHINY_ARTIFACT_RELIC_RANK      = "ARTIFACT_RELIC_RANK"
SHINY_AVOIDANCE                = "AVOIDANCE"
SHINY_CRITICAL                 = "CRITICAL"
SHINY_HASTE                    = "HASTE"
SHINY_INTELLECT                = "INTELLECT"
SHINY_ITEMLEVEL                = "ITEMLEVEL"
SHINY_LEECH                    = "LEECH"
SHINY_MASTERY                  = "MASTERY"
SHINY_PVPPOWER                 = "PVPPOWER"
SHINY_PVPRESILIENCE            = "PVPRESILIENCE"
SHINY_STAMINA                  = "STAMINA"
SHINY_STRENGTH                 = "STRENGTH"
SHINY_VERSATILITY              = "VERSATILITY"
SHINY_WEAPONDAMAGE             = "WEAPONDAMAGE"
SHINY_WEAPONDPS                = "WEAPONDPS"
SHINY_WEAPONSPEED              = "WEAPONSPEED"

-- Legacy (not used in Legion items)
SHINY_ARCANERESISTANCE         = "ARCANERESISTANCE"
SHINY_ATTACKPOWER              = "ATTACKPOWER"
SHINY_BLOCK                    = "BLOCK"
SHINY_DODGE                    = "DODGE"
SHINY_EXPERTISE                = "EXPERTISE"
SHINY_FIRERESISTANCE           = "FIRERESISTANCE"
SHINY_FROSTRESISTANCE          = "FROSTRESISTANCE"
SHINY_HIT                      = "HIT"
SHINY_NATURERESISTANCE         = "NATURERESISTANCE"
SHINY_PARRY                    = "PARRY"
SHINY_SHADOWRESISTANCE         = "SHADOWRESISTANCE"
SHINY_SPELLPENETRATION         = "SPELLPENETRATION"
SHINY_SPELLPOWER               = "SPELLPOWER"
SHINY_SPIRIT                   = "SPIRIT"

-- Special
SHINY_ENCHANT                  = "ENCHANT"
SHINY_EQUIP_PROC               = "EQUIP_PROC"
SHINY_EQUIP_PROC_TITLE        = "EQUIP_PROC_EFFECT"
SHINY_USABLE                   = "USABLE"
SHINY_UNUSABLE                 = "UNUSABLE"
SHINY_USELESS                  = "USELESS"

SHINY_ARTIFACT_RELIC_UNUSABLE  = "ARTIFACT_RELIC_UNUSABLE"
SHINY_ARTIFACT_RELIC_USABLE	   = "ARTIFACT_RELIC_USABLE"
SHINY_ARTIFACT_RELIC_ACTIVE	   = "ARTIFACT_RELIC_ACTIVE"


-- Dynamic
SHINY_ARTIFACT_RELIC           = "ARTIFACT_RELIC"
SHINY_CLASS                    = "CLASS"
SHINY_PRIMARYSTAT              = "PRIMARYSTAT"

-- NOP
SHINY_PASSTHRU                 = "PASSTHRU"



--[[
OLD DEFAULT COLORS

local COLOR_MAP = {
	[SHINY_AGILITY]          = "ffee03",
	[SHINY_ATTACKPOWER]      = "ff494f",
	[SHINY_ARCANERESISTANCE] = "a0f2ff",
	[SHINY_ARMOR]            = "b9b9b9",
	[SHINY_BLOCK]            = "a2793c",
	[SHINY_CRITICAL]         = "e8850d",
	[SHINY_WEAPONDAMAGE]     = "ff8930",
	[SHINY_DODGE]            = "bcff00",
	[SHINY_WEAPONDPS]        = "ff96ad",
	[SHINY_ENCHANT]          = "00ff00",
	[SHINY_EXPERTISE]        = "bbff00",
	[SHINY_FIRERESISTANCE]   = "ff8300",
	[SHINY_FROSTRESISTANCE]  = "188bff",
	[SHINY_HASTE]            = "b3eeff",
	[SHINY_HIT]              = "00ffc7",
	[SHINY_ITEMLEVEL]        = "f2c038",
	[SHINY_INTELLECT]        = "b395ff",
	[SHINY_MASTERY]	         = "ff73ba",
	[SHINY_NATURERESISTANCE] = "87ff3c",
	[SHINY_PARRY]            = "f600ff",
	[SHINY_PVPPOWER]         = "686eff",
	[SHINY_PVPRESILIENCE]    = "686eff",
	[SHINY_SPELLPOWER]	     = "ff73ba",
	[SHINY_WEAPONSPEED]      = "fff250",
	[SHINY_SPELLPENETRATION] = "ffffff",
	[SHINY_SPIRIT]           = "b7ffb8",
	[SHINY_SHADOWRESISTANCE] = "bd33b1",
	[SHINY_STAMINA]          = "dda357",
	[SHINY_STRENGTH]         = "ff000a",
	[SHINY_VERSATILITY]      = "b7aa88",
}

--]]

DEFAULT_COLORS = {
	[SHINY_AGILITY]                  = "ffee03",	-- Class Rogue: fff569
	[SHINY_ARMOR]                    = "b9b9b9",
	[SHINY_ARTIFACT_RELIC_ITEMLEVEL] = "abd473",
	[SHINY_ARTIFACT_RELIC_RANK]      = "0070de",
	[SHINY_CRITICAL]                 = "ff7d0a",
	[SHINY_HASTE]                    = "b3eeff",	-- Class Mage: 69ccf0
	[SHINY_INTELLECT]                = "9482c9",
	[SHINY_ITEMLEVEL]                = "f2c038",
	[SHINY_MASTERY]	                 = "f58cba",
	[SHINY_PVPPOWER]                 = "686eff",
	[SHINY_PVPRESILIENCE]            = "686eff",
	[SHINY_STAMINA]                  = "c79c6e",
	[SHINY_STRENGTH]                 = "c41f3b",
	[SHINY_VERSATILITY]              = "00ff96",
	[SHINY_LEECH]                    = "b7ffb8",
	[SHINY_AVOIDANCE]                = "a2793c",
	[SHINY_WEAPONDAMAGE]             = "ff8930",
	[SHINY_WEAPONDPS]                = "ff96ad",
	[SHINY_WEAPONSPEED]              = "fff250",
	
	-- Special
	[SHINY_ENCHANT]                  = "00ff00",
	[SHINY_EQUIP_PROC_TITLE]         = "ffe295",
	[SHINY_EQUIP_PROC]               = "ffd159",

	[SHINY_UNUSABLE]     	         = "ff2020",
	[SHINY_USELESS]     	         = "808080",

	[SHINY_ARTIFACT_RELIC_UNUSABLE]  = "ff2020",
	[SHINY_ARTIFACT_RELIC_USABLE]    = "c4a300",	-- ff7f3f
	[SHINY_ARTIFACT_RELIC_ACTIVE]    = "20ff20",

	-- Dynamic
	[SHINY_ARTIFACT_RELIC]           = false,
	[SHINY_CLASS]     	             = false,
	[SHINY_PRIMARYSTAT]              = false,

	-- NOP
	[SHINY_PASSTHRU]                 = false,

	[SHINY_ARCANERESISTANCE]         = "a0f2ff",
	[SHINY_FIRERESISTANCE]           = "ff8300",
	[SHINY_FROSTRESISTANCE]          = "188bff",
	[SHINY_NATURERESISTANCE]         = "87ff3c",
	[SHINY_SHADOWRESISTANCE]         = "bd33b1",
	
	-- Legacy (not used in Legion items)
	[SHINY_ATTACKPOWER]              = "ff494f",
	[SHINY_DODGE]                    = "bcff00",
	[SHINY_PARRY]                    = "f600ff",

	-- Unspecified
	["*"]	                         = "ffffff",	-- Default for unspecified
}


COLOR_NAME_MAP = {
	-- Stats
	[SHINY_AGILITY]                  = L["Agility"],
	[SHINY_ARMOR]                    = L["Armor"],
	[SHINY_CRITICAL]                 = L["Critical Strike"],
	[SHINY_HASTE]                    = L["Haste"],
	[SHINY_INTELLECT]                = L["Intellect"],
	[SHINY_MASTERY]                  = L["Mastery"],
	[SHINY_PVPPOWER]                 = L["PvP Power"],
	[SHINY_PVPRESILIENCE]            = L["PvP Resilience"],
	[SHINY_STAMINA]                  = L["Stamina"],
	[SHINY_STRENGTH]                 = L["Strength"],
	[SHINY_VERSATILITY]              = L["Versatility"],
	[SHINY_LEECH]                    = L["Leech"],
	[SHINY_AVOIDANCE]                = L["Avoidance"],

	[SHINY_WEAPONDAMAGE]             = L["Weapon Damage"],
	[SHINY_WEAPONDPS]                = L["Weapon DPS"],
	[SHINY_WEAPONSPEED]              = L["Weapon Speed"],
	
	[SHINY_ITEMLEVEL]                = L["Item Level"],

	[SHINY_ARCANERESISTANCE]         = L["Arcane Resistance"],
	[SHINY_FIRERESISTANCE]           = L["Fire Resistance"],
	[SHINY_FROSTRESISTANCE]          = L["Frost Resistance"],
	[SHINY_NATURERESISTANCE]         = L["Nature Resistance"],
	[SHINY_SHADOWRESISTANCE]         = L["Shadow Resistance"],
	
	-- Stats: Legacy (not used in Legion items)
	[SHINY_ATTACKPOWER]              = L["Attack Power"],
	[SHINY_DODGE]                    = L["Dodge"],
	[SHINY_PARRY]                    = L["Parry"],

	-- Relics 
	[SHINY_ARTIFACT_RELIC_ITEMLEVEL] = L["Artifact Item Level"],
	[SHINY_ARTIFACT_RELIC_RANK]      = L["Artifact Talent Rank"],
	[SHINY_ARTIFACT_RELIC_UNUSABLE]  = L["Artifact Relic: Unusable"],
	[SHINY_ARTIFACT_RELIC_USABLE]    = L["Artifact Relic: Usable (Inactive Spec)"],	-- ff7f3f
	[SHINY_ARTIFACT_RELIC_ACTIVE]    = L["Artifact Relic: Usable (Active Spec)"],

	-- Special
	[SHINY_ENCHANT]                  = L["Enchant Color"],
	[SHINY_EQUIP_PROC_TITLE]         = L["Chance on: Title"],
	[SHINY_EQUIP_PROC]               = L["Chance on: Effect"],
	[SHINY_UNUSABLE]                 = L["Unusable"],
	[SHINY_USELESS]                  = L["Useless"],
}


CONFIG_COLOR_MAP = {
	-- Stats
	standard = {
		name = L["Stats"],
		order = 10,
		items = {
			SHINY_AGILITY,
			SHINY_ARMOR,
			SHINY_CRITICAL,
			SHINY_HASTE,
			SHINY_INTELLECT,
			SHINY_MASTERY,
			SHINY_PVPPOWER,
			SHINY_PVPRESILIENCE,
			SHINY_STAMINA,
			SHINY_STRENGTH,
			SHINY_VERSATILITY,
			SHINY_LEECH,
			SHINY_AVOIDANCE,
		},
	},
	
	-- Stats: Legacy (not used in Legion items)
	legacy = {
		name = L["Stats (Legacy)"],
		order = 20,
		items = {
			SHINY_ATTACKPOWER,
			SHINY_DODGE,
			SHINY_PARRY,
		},
	},

	-- Relics
	relics = {
		name = L["Artifact Relics"],
		order = 30,
		items = {
			SHINY_ARTIFACT_RELIC_ITEMLEVEL,
			SHINY_ARTIFACT_RELIC_RANK,
			SHINY_ARTIFACT_RELIC_UNUSABLE,
			SHINY_ARTIFACT_RELIC_USABLE,
			SHINY_ARTIFACT_RELIC_ACTIVE,
		},
	},

	-- Misc
	misc = {
		name = L["Miscellaneous"],
		order = 40,
		items = {
			SHINY_WEAPONDAMAGE,
			SHINY_WEAPONDPS,
			SHINY_WEAPONSPEED,

			SHINY_ITEMLEVEL,

			SHINY_ARCANERESISTANCE,
			SHINY_FIRERESISTANCE,
			SHINY_FROSTRESISTANCE,
			SHINY_NATURERESISTANCE,
			SHINY_SHADOWRESISTANCE,
		},
	},

	-- Special
	special = {
		name = L["Special"],
		order = 50,
		items = {
			SHINY_ENCHANT,
			SHINY_EQUIP_PROC,
			SHINY_EQUIP_PROC_TITLE,
			SHINY_UNUSABLE,
			SHINY_USELESS,
		},
	},
}



--[[  C  O  N  F  I  G  ]]--

CONFIG_VERSION = 2.0


DEFAULT_OPTIONS = {
	DEBUG = false,

	ENABLE_CACHE = true,
	ENABLE_CHANCE = true,
	ENABLE_ENCHANT = true,
	ENABLE_EQUIP = true,
	ENABLE_EQUIP_TRANSFORMATION = true,
	ENABLE_MISC = true,
	ENABLE_PARTIAL_MATCHES = true,
	ENABLE_SOCKET_GEM = true,
	ENABLE_STAT_STRIP_COLORS = true,
	ENABLE_STAT_DIM_USELESS = true,
	ENABLE_USE = true,

	SHORTEN_SEPARATOR = ", ",
	SHORTEN_CHANCE = false,
	SHORTEN_ENCHANT = false,
	SHORTEN_EQUIP = false,
	SHORTEN_SOCKET_GEM = true,
	SHORTEN_USE = false,
}



--[[  S  T  A  T  S  ]]--

LEGACY_STAT_MAP = {
	[SHINY_ATTACKPOWER]       = true,
	[SHINY_DODGE]             = true,
	[SHINY_PARRY]             = true,
}


PRIMARY_STAT_MAP = {
	[LE_UNIT_STAT_STRENGTH]  = SHINY_STRENGTH,
	[LE_UNIT_STAT_AGILITY]   = SHINY_AGILITY,
	[LE_UNIT_STAT_INTELLECT] = SHINY_INTELLECT,

	[SHINY_AGILITY] = true,
	[SHINY_STRENGTH] = true,
	[SHINY_INTELLECT] = true,
}

STAT_NAME_MAP = {
	[L["Agility"]]         = SHINY_AGILITY,
	[L["Avoidance"]]       = SHINY_AVOIDANCE,
	[L["Critical Strike"]] = SHINY_CRITICAL,
	[L["Haste"]]           = SHINY_HASTE,
	[L["Intellect"]]       = SHINY_INTELLECT,
	[L["Leech"]]           = SHINY_LEECH,
	[L["Mastery"]]         = SHINY_MASTERY,
	[L["PvP Power"]]       = SHINY_PVPPOWER,
	[L["PvP Resilience"]]  = SHINY_PVPRESILIENCE,
	[L["Stamina"]]         = SHINY_STAMINA,
	[L["Strength"]]        = SHINY_STRENGTH,
	[L["Versatility"]]     = SHINY_VERSATILITY,
	[L["Arcane Resistance"]]  = SHINY_ARCANERESISTANCE,
	[L["Fire Resistance"]]    = SHINY_FIRERESISTANCE,
	[L["Frost Resistance"]]   = SHINY_FROSTRESISTANCE,
	[L["Nature Resistance"]]  = SHINY_NATURERESISTANCE,
	[L["Shadow Resistance"]]  = SHINY_SHADOWRESISTANCE,
}

STAT_CLASS_MAP = {
	[SHINY_STRENGTH] = {
		[CLASS_PALADIN] = {
			false, -- Paladin: Holy
			true, -- Paladin: Protection
			true, -- Paladin: Retribution
		},
		[CLASS_WARRIOR] = true,
		[CLASS_DEATHKNIGHT] = true,
	},

	[SHINY_AGILITY] = {
		[CLASS_DEMONHUNTER] = true,
		[CLASS_DRUID] = {
			false, -- Druid: Balance
			true,  -- Druid: Feral
			true,  -- Druid: Guardian
			false, -- Druid: Restoration
		},
		[CLASS_HUNTER] = true,
		[CLASS_ROGUE] = true,
		[CLASS_SHAMAN] = {
			false, -- Shaman: Elemental
			true,  -- Shaman: Enhancement
			false, -- Shaman: Restoration
		},
	},

	[SHINY_INTELLECT] = {
		[CLASS_MAGE] = true,
		[CLASS_PALADIN] = {
			true,  -- Paladin: Holy
			false, -- Paladin: Protection
			false, -- Paladin: Retribution
		},
		[CLASS_DRUID] = {
			true, -- Druid: Balance
			false, -- Druid: Feral
			false, -- Druid: Guardian
			true, -- Druid: Restoration
		},
		[CLASS_PRIEST] = true,
		[CLASS_SHAMAN] = {
			true, -- Shaman: Elemental
			false, -- Shaman: Enhancement
			true, -- Shaman: Restoration
		},
		[CLASS_WARLOCK] = true,
		[CLASS_MONK] = true,
	},

	[SHINY_STAMINA] = {
		[CLASS_MAGE] = true,
		[CLASS_PALADIN] = true,
		[CLASS_WARRIOR] = true,
		[CLASS_DRUID] = true,
		[CLASS_DEATHKNIGHT] = true,
		[CLASS_HUNTER] = true,
		[CLASS_PRIEST] = true,
		[CLASS_ROGUE] = true,
		[CLASS_SHAMAN] = true,
		[CLASS_WARLOCK] = true,
		[CLASS_MONK] = true,
		[CLASS_DEMONHUNTER] = true,
	},
}



--[[  R  E  L  I  C  S  ]]--

RELIC_ARCANE = L["Arcane Artifact Relic"]
RELIC_BLOOD  = L["Blood Artifact Relic"]
RELIC_FEL    = L["Fel Artifact Relic"]
RELIC_FIRE   = L["Fire Artifact Relic"]
RELIC_FROST  = L["Frost Artifact Relic"]
RELIC_HOLY   = L["Holy Artifact Relic"]
RELIC_IRON   = L["Iron Artifact Relic"]
RELIC_LIFE   = L["Life Artifact Relic"]
RELIC_SHADOW = L["Shadow Artifact Relic"]
RELIC_STORM  = L["Storm Artifact Relic"]
RELIC_WATER  = L["Water Artifact Relic"]


RELIC_LIST = {
	[RELIC_SHADOW] = true,
	[RELIC_IRON]   = true,
	[RELIC_BLOOD]  = true,
	[RELIC_STORM]  = true,
	[RELIC_FEL]    = true,
	[RELIC_ARCANE] = true,
	[RELIC_FIRE]   = true,
	[RELIC_FROST]  = true,
	[RELIC_HOLY]   = true,
	[RELIC_LIFE]   = true,
	[RELIC_WATER]  = true,
}


CLASS_SPEC_ID_MAP = {
	[CLASS_MAGE] = {
		62, -- Mage: Arcane
		63, -- Mage: Fire
		64, -- Mage: Frost
	},
	[CLASS_PALADIN] = {
		65, -- Paladin: Holy
		66, -- Paladin: Protection
		70, -- Paladin: Retribution
	},
	[CLASS_WARRIOR] = {
		71, -- Warrior: Arms
		72, -- Warrior: Fury
		73, -- Warrior: Protection
	},
	[CLASS_DRUID] = {
		102, -- Druid: Balance
		103, -- Druid: Feral
		104, -- Druid: Guardian
		105, -- Druid: Restoration
	},
	[CLASS_DEATHKNIGHT] = {
		250, -- Death Knight: Blood
		251, -- Death Knight: Frost
		252, -- Death Knight: Unholy
	},
	[CLASS_HUNTER] = {
		253, -- Hunter: Beast Mastery
		254, -- Hunter: Marksmanship
		255, -- Hunter: Survival
	},
	[CLASS_PRIEST] = {
		256, -- Priest: Discipline
		257, -- Priest: Holy
		258, -- Priest: Shadow
	},
	[CLASS_ROGUE] = {
		259, -- Rogue: Assassination
		260, -- Rogue: Combat
		261, -- Rogue: Subtlety
	},
	[CLASS_SHAMAN] = {
		262, -- Shaman: Elemental
		263, -- Shaman: Enhancement
		264, -- Shaman: Restoration
	},
	[CLASS_WARLOCK] = {
		265, -- Warlock: Affliction
		266, -- Warlock: Demonology
		267, -- Warlock: Destruction
	},
	[CLASS_MONK] = {
		268, -- Monk: Brewmaster
		269, -- Monk: Windwalker
		270, -- Monk: Mistweaver
	},
	[CLASS_DEMONHUNTER] = {
		577, -- Demon Hunter: Havoc
		581, -- Demon Hunter: Vengeance
	},
}


CLASS_RELIC_MAP = {
	[CLASS_DEATHKNIGHT] = {
		{
			[RELIC_BLOOD] = true,
			[RELIC_IRON] = true,
			[RELIC_SHADOW] = true,
		},
		{	
			[RELIC_FROST] = true,
			[RELIC_FROST] = true,
			[RELIC_SHADOW] = true,
		},
		{
			[RELIC_BLOOD] = true,
			[RELIC_FIRE] = true,
			[RELIC_SHADOW] = true,
		}
	},
	[CLASS_HUNTER] = {
		{
			[RELIC_ARCANE] = true,
			[RELIC_IRON] = true,
			[RELIC_STORM] = true,
		},
		{	
			[RELIC_BLOOD] = true,
			[RELIC_LIFE] = true,
			[RELIC_STORM] = true,
		},
		{
			[RELIC_BLOOD] = true,
			[RELIC_IRON] = true,
			[RELIC_STORM] = true,
		}
	},
	[CLASS_MAGE] = {
		{
			[RELIC_ARCANE] = true,
			[RELIC_ARCANE] = true,
			[RELIC_FROST] = true,
		},
		{	
			[RELIC_ARCANE] = true,
			[RELIC_FIRE] = true,
			[RELIC_FIRE] = true,
		},
		{
			[RELIC_ARCANE] = true,
			[RELIC_FROST] = true,
			[RELIC_FROST] = true,
		}
	},
	[CLASS_MONK] = {
		{
			[RELIC_IRON] = true,
			[RELIC_LIFE] = true,
			[RELIC_STORM] = true,
		},
		{	
			[RELIC_FROST] = true,
			[RELIC_LIFE] = true,
			[RELIC_STORM] = true,
		},
		{
			[RELIC_IRON] = true,
			[RELIC_STORM] = true,
			[RELIC_STORM] = true,
		}
	},
	[CLASS_PALADIN] = {
		{
			[RELIC_HOLY] = true,
			[RELIC_HOLY] = true,
			[RELIC_LIFE] = true,
		},
		{	
			[RELIC_ARCANE] = true,
			[RELIC_HOLY] = true,
			[RELIC_IRON] = true,
		},
		{
			[RELIC_FIRE] = true,
			[RELIC_HOLY] = true,
			[RELIC_HOLY] = true,
		}
	},
	[CLASS_PRIEST] = {
		{
			[RELIC_HOLY] = true,
			[RELIC_HOLY] = true,
			[RELIC_SHADOW] = true,
		},
		{	
			[RELIC_HOLY] = true,
			[RELIC_HOLY] = true,
			[RELIC_LIFE] = true,
		},
		{
			[RELIC_BLOOD] = true,
			[RELIC_SHADOW] = true,
			[RELIC_SHADOW] = true,
		}
	},
	[CLASS_ROGUE] = {
		{
			[RELIC_BLOOD] = true,
			[RELIC_IRON] = true,
			[RELIC_SHADOW] = true,
		},
		{	
			[RELIC_BLOOD] = true,
			[RELIC_IRON] = true,
			[RELIC_STORM] = true,
		},
		{
			[RELIC_FEL] = true,
			[RELIC_FEL] = true,
			[RELIC_SHADOW] = true,
		}
	},
	[CLASS_SHAMAN] = {
		{
			[RELIC_FROST] = true,
			[RELIC_STORM] = true,
			[RELIC_STORM] = true,
		},
		{	
			[RELIC_FIRE] = true,
			[RELIC_IRON] = true,
			[RELIC_STORM] = true,
		},
		{
			[RELIC_FROST] = true,
			[RELIC_LIFE] = true,
			[RELIC_LIFE] = true,
		}
	},
	[CLASS_WARLOCK] = {
		{
			[RELIC_BLOOD] = true,
			[RELIC_SHADOW] = true,
			[RELIC_SHADOW] = true,
		},
		{	
			[RELIC_FEL] = true,
			[RELIC_FIRE] = true,
			[RELIC_SHADOW] = true,
		},
		{
			[RELIC_FEL] = true,
			[RELIC_FEL] = true,
			[RELIC_FIRE] = true,
		}
	},
	[CLASS_WARRIOR] = {
		{
			[RELIC_BLOOD] = true,
			[RELIC_IRON] = true,
			[RELIC_SHADOW] = true,
		},
		{	
			[RELIC_FIRE] = true,
			[RELIC_IRON] = true,
			[RELIC_STORM] = true,
		},
		{
			[RELIC_BLOOD] = true,
			[RELIC_FIRE] = true,
			[RELIC_IRON] = true,
		}
	},
	[CLASS_DRUID] = {
		{
			[RELIC_ARCANE] = true,
			[RELIC_ARCANE] = true,
			[RELIC_LIFE] = true,
		},
		{	
			[RELIC_BLOOD] = true,
			[RELIC_FROST] = true,
			[RELIC_LIFE] = true,
		},
		{
			[RELIC_BLOOD] = true,
			[RELIC_FIRE] = true,
			[RELIC_LIFE] = true,
		},
		{
			[RELIC_FROST] = true,
			[RELIC_LIFE] = true,
			[RELIC_LIFE] = true,
		},
	},
	[CLASS_DEMONHUNTER] = {
		{
			[RELIC_FEL] = true,
			[RELIC_FEL] = true,
			[RELIC_SHADOW] = true,
		},
		{	
			[RELIC_IRON] = true,
			[RELIC_ARCANE] = true,
			[RELIC_FEL] = true,
		},
	},
}


for className,classTable in pairs(CLASS_RELIC_MAP) do
	for specIndex, specRelicTable in ipairs(classTable) do
		for relicName,_ in pairs(specRelicTable) do
			classTable[relicName] = true
		end
	end
end